@@ -49,6 +49,7 @@ KCMAkonadiContactActions::KCMAkonadiContactActions(QWidget *parent, const QVaria
 
     mConfigManager = addConfig(ContactActionsSettings::self(), this);
 
+    ui.DialPhoneNumberAction->addItem(i18n("System Default"), ContactActionsSettings::UseSystemDefault);
     ui.DialPhoneNumberAction->addItem(i18n("Skype"), ContactActionsSettings::UseSkype);
     ui.DialPhoneNumberAction->addItem(i18n("Ekiga"), ContactActionsSettings::UseEkiga);
     ui.DialPhoneNumberAction->addItem(i18n("SflPhone"), ContactActionsSettings::UseSflPhone);
@@ -56,6 +57,7 @@ KCMAkonadiContactActions::KCMAkonadiContactActions(QWidget *parent, const QVaria
 
     connect(ui.DialPhoneNumberAction, QOverload<int>::of(&KComboBox::currentIndexChanged), this, &KCMAkonadiContactActions::slotDialPhoneNumberActionChanged);
 
+    ui.SendSmsAction->addItem(i18n("System Default"), ContactActionsSettings::UseSystemDefaultSms);
     ui.SendSmsAction->addItem(i18n("Skype"), ContactActionsSettings::UseSkypeSms);
     ui.SendSmsAction->addItem(i18n("SflPhone"), ContactActionsSettings::UseSflPhoneSms);
     ui.SendSmsAction->addItem(i18n("External Application"), ContactActionsSettings::UseExternalSmsApplication);
@@ -89,9 +91,9 @@ void KCMAkonadiContactActions::slotSmsPhoneNumberActionChanged(int value)
 {
     ContactActionsSettings::EnumSendSmsAction enumValue = static_cast<ContactActionsSettings::EnumSendSmsAction>(ui.SendSmsAction->itemData(value).toInt());
     if (enumValue == ContactActionsSettings::UseExternalSmsApplication) {
-        ui.stackedWidget_3->setCurrentIndex(1);
+        ui.smsDetailsStack->setCurrentIndex(1);
     } else {
-        ui.stackedWidget_3->setCurrentIndex(0);
+        ui.smsDetailsStack->setCurrentIndex(0);
     }
     Q_EMIT changed(true);
 }
@@ -100,9 +102,9 @@ void KCMAkonadiContactActions::slotDialPhoneNumberActionChanged(int value)
 {
     ContactActionsSettings::EnumDialPhoneNumberAction enumValue = static_cast<ContactActionsSettings::EnumDialPhoneNumberAction>(ui.DialPhoneNumberAction->itemData(value).toInt());
     if (enumValue == ContactActionsSettings::UseExternalPhoneApplication) {
-        ui.stackedWidget_2->setCurrentIndex(1);
+        ui.phoneDetailsStack->setCurrentIndex(1);
     } else {
-        ui.stackedWidget_2->setCurrentIndex(0);
+        ui.phoneDetailsStack->setCurrentIndex(0);
     }
     Q_EMIT changed(true);
 }
