@@ -59,7 +59,7 @@ public:
         }
 
         QVBoxLayout *layout = new QVBoxLayout(mParent);
-        layout->setMargin(0);
+        layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         layout->addWidget(mEditorWidget);
     }
