@@ -51,7 +51,7 @@ public:
     void adaptHeaderSizes();
 
     void loadContactGroup(const KContacts::ContactGroup &group);
-    bool storeContactGroup(KContacts::ContactGroup &group);
+    Q_REQUIRED_RESULT bool storeContactGroup(KContacts::ContactGroup &group);
     void setupMonitor();
 
     ContactGroupEditor::Mode mMode = ContactGroupEditor::Mode::CreateMode;
