@@ -64,7 +64,7 @@ public:
     /**
      * Returns the text of the email address requester.
      */
-    QString text() const;
+    Q_REQUIRED_RESULT QString text() const;
 
     /**
      * Returns the line edit that is used by the email address requester.
