@@ -20,7 +20,7 @@
 
 #include "emailaddressselectiondialog.h"
 
-#include <qapplication.h>
+#include <QApplication>
 
 int main(int argc, char **argv)
 {
