@@ -22,11 +22,16 @@
 
 #ifndef ADDRESSESLOCATIONWIDGET_H
 #define ADDRESSESLOCATIONWIDGET_H
-#include <QWidget>
+#include <QSplitter>
 #include <KContacts/Addressee>
+
+class QTreeView;
+
 namespace ContactEditor {
-class AbstractAddressLocationWidget;
-class AddressesLocationWidget : public QWidget
+class AddressModel;
+class AddressLocationWidget;
+
+class AddressesLocationWidget : public QSplitter
 {
     Q_OBJECT
 public:
@@ -38,7 +43,10 @@ public:
 
     void setReadOnly(bool readOnly);
 private:
-    AbstractAddressLocationWidget *mAbstractAddressLocationWidget = nullptr;
+    AddressLocationWidget *mAddressLocationWidget = nullptr;
+    QTreeView *mAddressesLocationView = nullptr;
+    AddressModel *mAddressModel = nullptr;
+    bool mReadOnly = false;
 };
 }
 #endif // ADDRESSESLOCATIONWIDGET_H
