@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2019 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -32,7 +32,9 @@
 #include <QCheckBox>
 #include <QPushButton>
 #include <QStackedWidget>
+
 using namespace ContactEditor;
+
 struct LocaleAwareLessThan : std::binary_function<QString, QString, bool> {
     bool operator()(const QString &s1, const QString &s2) const
     {
@@ -124,7 +126,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
 
     QWidget *addButtonWidget = new QWidget(this);
     QHBoxLayout *addButtonWidgetLayout = new QHBoxLayout(addButtonWidget);
-    addButtonWidgetLayout->setMargin(0);
+    addButtonWidgetLayout->setContentsMargins(0, 0, 0, 0);
     mAddAddress = new QPushButton(i18n("Add Address"), this);
     mAddAddress->setObjectName(QStringLiteral("addbuttonaddress"));
     connect(mAddAddress, &QPushButton::clicked, this, &AddressLocationWidget::slotAddAddress);
@@ -134,7 +136,7 @@ AddressLocationWidget::AddressLocationWidget(QWidget *parent)
 
     QWidget *modifyButtonWidget = new QWidget(this);
     QHBoxLayout *modifyButtonWidgetLayout = new QHBoxLayout(modifyButtonWidget);
-    modifyButtonWidgetLayout->setMargin(0);
+    modifyButtonWidgetLayout->setContentsMargins(0, 0, 0, 0);
     mButtonStack->addWidget(modifyButtonWidget);
 
     mModifyAddress = new QPushButton(i18n("Update Address"), this);
