@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2019 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -20,13 +20,16 @@
     02110-1301, USA.
 */
 
-#include "addresstypedialog.h"
 #include "selectaddresstypecombobox.h"
+#include "addresstypedialog.h"
+#include <QPointer>
+
 #include <KLocalizedString>
-#include <autoqpointer_p.h>
+
 using namespace ContactEditor;
+
 SelectAddressTypeComboBox::SelectAddressTypeComboBox(QWidget *parent)
-    : KComboBox(parent)
+    : QComboBox(parent)
     , mType(KContacts::Address::Home)
     , mLastSelected(0)
 {
@@ -40,7 +43,7 @@ SelectAddressTypeComboBox::SelectAddressTypeComboBox(QWidget *parent)
 
     update();
 
-    connect(this, SIGNAL(activated(int)), this, SLOT(selected(int)));
+    connect(this, qOverload<int>(&QComboBox::activated), this, &SelectAddressTypeComboBox::selected);
 }
 
 SelectAddressTypeComboBox::~SelectAddressTypeComboBox()
@@ -99,7 +102,7 @@ void SelectAddressTypeComboBox::selected(int pos)
 
 void SelectAddressTypeComboBox::otherSelected()
 {
-    AutoQPointer<AddressTypeDialog> dlg = new AddressTypeDialog(mType, this);
+    QPointer<AddressTypeDialog> dlg = new AddressTypeDialog(mType, this);
     if (dlg->exec()) {
         mType = dlg->type();
         if (!mTypeList.contains(mType)) {
@@ -108,5 +111,6 @@ void SelectAddressTypeComboBox::otherSelected()
     } else {
         setType(KContacts::Address::Type(mTypeList.at(mLastSelected)));
     }
+    delete dlg;
     update();
 }
