@@ -20,7 +20,7 @@
 */
 
 #include "contactselecttypecomboboxtest.h"
-#include "../contactselecttypecombobox.h"
+#include "../mail/mailtypecombobox.h"
 #include <QTest>
 
 ContactSelectTypeComboboxTest::ContactSelectTypeComboboxTest(QObject *parent)
@@ -34,10 +34,8 @@ ContactSelectTypeComboboxTest::~ContactSelectTypeComboboxTest()
 
 void ContactSelectTypeComboboxTest::shouldHaveDefaultValue()
 {
-    ContactEditor::ContactSelectTypeCombobox w;
-    w.initialize();
-    QVERIFY(!w.selectTypeList().isEmpty());
-    QCOMPARE(w.count(), w.selectTypeList().count() + 1);
+    ContactEditor::MailTypeCombobox w;
+    QCOMPARE(w.count(), 4);
 }
 
 QTEST_MAIN(ContactSelectTypeComboboxTest)
