@@ -29,7 +29,7 @@ CategoriesEditWidget::CategoriesEditWidget(QWidget *parent)
     : ContactEditor::CategoriesEditAbstractWidget(parent)
 {
     QHBoxLayout *layout = new QHBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
 }
 
 CategoriesEditWidget::~CategoriesEditWidget()
@@ -38,12 +38,15 @@ CategoriesEditWidget::~CategoriesEditWidget()
 
 void CategoriesEditWidget::setReadOnly(bool readOnly)
 {
+    Q_UNUSED(readOnly);
 }
 
 void CategoriesEditWidget::loadContact(const KContacts::Addressee &contact)
 {
+    Q_UNUSED(contact);
 }
 
 void CategoriesEditWidget::storeContact(KContacts::Addressee &contact) const
 {
+    Q_UNUSED(contact);
 }
