@@ -1,7 +1,7 @@
 /*
     This file is part of Contact Editor.
 
-    Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
+    Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -33,7 +33,7 @@ MessageFormattingWidget::MessageFormattingWidget(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *topLayout = new QVBoxLayout(this);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     QLabel *label = new QLabel(i18n("Show messages received from this contact as:"), this);
     label->setObjectName(QStringLiteral("label"));
     topLayout->addWidget(label);
@@ -84,13 +84,13 @@ void MessageFormattingWidget::storeContact(KContacts::Addressee &contact) const
     } else if (index == 2) {
         mailPreferedFormatting = QStringLiteral("HTML");
     }
-    ContactEditor::Utils::storeCustom(contact, QLatin1String("MailPreferedFormatting"), mailPreferedFormatting);
+    ContactEditor::Utils::storeCustom(contact, QStringLiteral("MailPreferedFormatting"), mailPreferedFormatting);
 
     QString mailAllowToRemoteContent;
     if (mAllowRemoteContent->isChecked()) {
-        mailAllowToRemoteContent = QLatin1String("TRUE");
+        mailAllowToRemoteContent = QStringLiteral("TRUE");
     }
-    ContactEditor::Utils::storeCustom(contact, QLatin1String("MailAllowToRemoteContent"), mailAllowToRemoteContent);
+    ContactEditor::Utils::storeCustom(contact, QStringLiteral("MailAllowToRemoteContent"), mailAllowToRemoteContent);
 }
 
 void MessageFormattingWidget::setReadOnly(bool readOnly)
