@@ -2,7 +2,7 @@
     This file is part of Contact Editor.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016-2018 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2019 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -28,7 +28,7 @@
 #include <kcontacts/resourcelocatorurl.h>
 class QToolButton;
 namespace ContactEditor {
-class ContactSelectTypeCombobox;
+class WebSelectTypeCombobox;
 class PreferredLineEditWidget;
 class WebWidget : public QWidget
 {
@@ -61,7 +61,7 @@ private:
     PreferredLineEditWidget *mWebSiteEdit = nullptr;
     QToolButton *mAddButton = nullptr;
     QToolButton *mRemoveButton = nullptr;
-    ContactEditor::ContactSelectTypeCombobox *mWebType = nullptr;
+    ContactEditor::WebSelectTypeCombobox *mWebType = nullptr;
 };
 }
 #endif // WEBWIDGET_H
